@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 #############################################################################
 ##
@@ -23,12 +23,11 @@
 ##
 #############################################################################
 
-"""This module exposes PyQt4.QtGui module"""
+"""This module exposes QtWebKit module"""
 
-from taurusqtoptions import QT_API, QT_API_PYQT, QT_API_PYSIDE
+from taurus.core.util.log import info
+info("import of QtWebKit from taurus.qt is deprecated. "
+     "Use taurus.external.qt instead")
+del info
 
-# Now peform the imports.
-if QT_API == QT_API_PYQT:
-    from PyQt4.QtWebKit import *  # analysis:ignore
-elif QT_API == QT_API_PYSIDE:
-    from PySide.QtWebKit import *  # analysis:ignore
+from taurus.external.qt.QtWebKit import *
