@@ -28,7 +28,7 @@ emitter.py: This module provides a task scheduler used by TaurusGrid and TaurusD
 
 from functools import partial
 import taurus
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.core.util.log import Logger
 from taurus.core.util.singleton import Singleton
 import Queue,traceback
