@@ -29,7 +29,7 @@ __all__ = ["TaurusConfigLabel"]
 
 __docformat__ = 'restructuredtext'
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 
 import taurus.core
 from taurus.qt.qtgui.util import QT_DEVICE_STATE_PALETTE
