@@ -30,7 +30,7 @@
 __docformat__ = 'restructuredtext'
 
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from guiqwt.tools import CommandTool, ToggleTool, DefaultToolbarID, QActionGroup, add_actions
 from guiqwt.signals import SIG_ITEMS_CHANGED
 
