@@ -31,7 +31,7 @@ __docformat__ = 'restructuredtext'
 
 from datetime import datetime
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 import PyTango
 
 import taurus.core
@@ -112,7 +112,6 @@ class TaurusForm(TaurusWidget):
         
         self._connectButtons()
         
-        
         #Actions (they automatically populate the context menu)
         self.setContextMenuPolicy(Qt.Qt.ActionsContextMenu)
         
@@ -130,11 +129,20 @@ class TaurusForm(TaurusWidget):
         self.addAction(self.changeLabelsAction)
         self.connect(self.changeLabelsAction, Qt.SIGNAL("triggered()"), self.onChangeLabelsAction)
         
+        self.compactModeAction = Qt.QAction('Compact mode (all items)', self)
+        self.compactModeAction.setCheckable(True)
+        self.addAction(self.compactModeAction)
+        self.connect(self.compactModeAction, Qt.SIGNAL("triggered(bool)"), self.setCompact)
+        
         self.resetModifiableByUser()
         self.setSupportedMimeTypes([TAURUS_MODEL_LIST_MIME_TYPE, TAURUS_DEV_MIME_TYPE, TAURUS_ATTR_MIME_TYPE, TAURUS_MODEL_MIME_TYPE, 'text/plain'])
 
+        
+        self.resetCompact()
+        
         #properties
         self.registerConfigProperty(self.isWithButtons, self.setWithButtons, 'withButtons')
+        self.registerConfigProperty(self.isCompact, self.setCompact, 'compact')
 
     def __getitem__(self, key):
         '''provides a list-like interface: items of the form can be accessed using slice notation'''
@@ -337,6 +345,19 @@ class TaurusForm(TaurusWidget):
         
     def resetWithButtons(self):
         self.setWithButtons(True)
+        
+    def setCompact(self, compact):
+        self._compact = compact
+        for item in self.getItems():
+            item.setCompact(compact)
+        self.compactModeAction.setChecked(compact)
+
+    def isCompact(self):
+        return self._compact
+    
+    def resetCompact(self):
+        from taurus import tauruscustomsettings
+        self.setCompact(getattr(tauruscustomsettings,'T_FORM_COMPACT',{}))
     
     def dropEvent(self, event):
         '''reimplemented to support dropping of modelnames in forms'''
@@ -398,7 +419,9 @@ class TaurusForm(TaurusWidget):
             klass, args, kwargs = self.getFormWidget(model=model)
             widget = klass(frame,*args,**kwargs)
             widget.setMinimumHeight(20)  #@todo UGLY... See if this can be done in other ways... (this causes trouble with widget that need more vertical space , like PoolMotorTV)
-            try: 
+
+            try:
+                widget.setCompact(self.isCompact())
                 widget.setModel(model)
                 widget.setParent(frame)
             except: 
@@ -489,6 +512,8 @@ class TaurusForm(TaurusWidget):
     modifiableByUser = Qt.pyqtProperty("bool", TaurusWidget.isModifiableByUser, 
                                                setModifiableByUser,
                                                TaurusWidget.resetModifiableByUser)
+    
+    compact = Qt.pyqtProperty("bool", isCompact, setCompact, resetCompact)
       
     
 
