@@ -29,7 +29,7 @@ __all__ = ["QBaseTableWidget"]
 
 __docformat__ = 'restructuredtext'
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.qt.qtgui.model import QBaseModelWidget
 
 
@@ -43,6 +43,7 @@ class QBaseTableWidget(QBaseModelWidget):
             klass = Qt.QTableView
         table = klass()
         table.setSortingEnabled(True)
+        table.sortByColumn(0, Qt.Qt.AscendingOrder)
         table.setAlternatingRowColors(True)
         table.setSelectionBehavior(Qt.QAbstractItemView.SelectRows)
         table.setSelectionMode(Qt.QAbstractItemView.ExtendedSelection)
