@@ -33,7 +33,7 @@ import time
 import threading
 import os.path
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.core.util.log import Logger
 
 _LOGGER = None
@@ -87,8 +87,8 @@ class Grabber(Qt.QObject, Logger):
         try:
             pixmap = Qt.QPixmap.grabWidget(widget)
             if fileName.endswith('.svg'):
-                import taurus.qt.QtSvg
-                generator = taurus.qt.QtSvg.QSvgGenerator()
+                from taurus.external.qt import QtSvg
+                generator = QtSvg.QSvgGenerator()
                 generator.setFileName(fileName)
                 generator.setSize(pixmap.size());
                 if hasattr(generator, 'setViewBox'):
@@ -133,4 +133,4 @@ class Grabber(Qt.QObject, Logger):
 def grabWidget(widget, fileName, period=None):
     return Grabber.grabWidget(widget, fileName, period=period)
     
-grabWidget.__doc__ = Grabber.grabWidget.__doc__
\ No newline at end of file
+grabWidget.__doc__ = Grabber.grabWidget.__doc__
